use super::{Deserialize, HashMap, Serialize, String, Vec};

// GET /v1/status/IcingaApplication
#[derive(Serialize, Deserialize, Debug, Clone, PartialEq)]
pub struct Response {
    pub results: Vec<Result>,
}

#[derive(Serialize, Deserialize, Debug, Clone, PartialEq)]
pub struct Result {
    pub perfdata: Vec<HashMap<String, String>>,
    pub status: Status,
}

#[derive(Serialize, Deserialize, Debug, Clone, PartialEq)]
pub struct Status {
    pub icingaapplication: Internal,
}

#[derive(Serialize, Deserialize, Debug, Clone, PartialEq)]
pub struct Internal {
    pub app: App,
}

#[derive(Serialize, Deserialize, Debug, Clone, PartialEq)]
pub struct App {
    enable_event_handlers: Option<bool>,
    enable_flapping: Option<bool>,
    enable_host_checks: Option<bool>,
    enable_notifications: Option<bool>,
    enable_perfdata: Option<bool>,
    enable_service_checks: Option<bool>,
    node_name: String,
    pid: f64,
    program_start: f64,
    version: String,
}

impl App {
    #[must_use]
    pub const fn is_event_handlers_enabled(&self) -> Option<bool> {
        self.enable_event_handlers
    }

    #[must_use]
    pub const fn is_flapping_enabled(&self) -> Option<bool> {
        self.enable_flapping
    }

    #[must_use]
    pub const fn are_host_checks_enabled(&self) -> Option<bool> {
        self.enable_host_checks
    }

    #[must_use]
    pub const fn are_notifications_enabled(&self) -> Option<bool> {
        self.enable_notifications
    }

    #[must_use]
    pub const fn is_perfdata_enabled(&self) -> Option<bool> {
        self.enable_perfdata
    }

    #[must_use]
    pub const fn are_service_checks_enabled(&self) -> Option<bool> {
        self.enable_service_checks
    }

    #[must_use]
    #[inline]
    pub fn node_name(&self) -> &str {
        self.node_name.as_str()
    }

    #[allow(clippy::cast_possible_truncation)]
    #[must_use]
    pub const fn pid(&self) -> i64 {
        self.pid as i64
    }

    #[must_use]
    pub const fn program_start(&self) -> f64 {
        self.program_start
    }

    #[must_use]
    #[inline]
    pub fn version(&self) -> &str {
        self.version.as_str()
    }
}
