extern crate std;

use alloc::boxed::Box;
use hyper::StatusCode;
use thiserror::Error as ThisError;

#[derive(ThisError, Debug)]
pub enum Error {
    #[error(transparent)]
    RequestBuildError(#[from] RequestBuildError),
    #[error(transparent)]
    HyperError(#[from] hyper::Error),
    #[error("The server didn't apply your action (code: {api_status}: {message})")]
    ActionStatusCode {
        http_status: StatusCode,
        api_status: f64,
        message: Box<str>,
    },
    #[error("The server didn't provide a successfull response ({0})")]
    StatusCode(StatusCode),
    #[error("The response didn't deserialize properly")]
    JsonDeserializationError(#[from] serde_json::Error),
}

#[allow(clippy::module_name_repetitions)]
#[derive(ThisError, Debug)]
pub enum RequestBuildError {
    #[error(transparent)]
    HyperHttpError(#[from] hyper::http::Error),
    #[error(transparent)]
    JsonSerializationError(#[from] serde_json::Error),
}

#[allow(clippy::module_name_repetitions)]
#[derive(ThisError, Debug)]
pub enum ApplicationStatusError {
    #[error(transparent)]
    HyperHttpError(#[from] hyper::http::Error),
    #[error(transparent)]
    HyperError(#[from] hyper::Error),
    #[error("The server didn't provide a successfull response")]
    StatusCode(StatusCode),
    #[error("The response didn't deserialize properly")]
    JsonDeserializationError(#[from] serde_json::Error),
}
